@@ -1,6 +1,11 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 """
+Utilities for Liang and Granger causality analysis in atmospheric and climate data
+
+This module provides causality analysis tools for time series data commonly
+used in atmospheric and climate research.
+
 Utilities for Liang and Granger causality analysis
 https://github.com/LinkedEarth/Pyleoclim_util
 """
@@ -12,9 +17,10 @@ import numpy as np
 from statsmodels.tsa.stattools import grangercausalitytests
 from tqdm import tqdm
 from scipy.stats.mstats import mquantiles
+from typing import Any, Dict, List, Union
 
 
-def ar1_fit_evenly(y):
+def ar1_fit_evenly(y: np.ndarray) -> float:
     """Returns the lag-1 autocorrelation from AR(1) fit.
 
     Uses `statsmodels.tsa.arima.model.ARIMA <https://www.statsmodels.org/devel/generated/statsmodels.tsa.arima.model.ARIMA.html>`_. to
@@ -49,7 +55,7 @@ def ar1_fit_evenly(y):
     return g
 
 
-def sm_ar1_sim(n, p, g, sig):
+def sm_ar1_sim(n: int, p: int, g: float, sig: float) -> np.ndarray:
     """Produce p realizations of an AR1 process of length n with lag-1 autocorrelation g using statsmodels
 
     Parameters
@@ -73,8 +79,8 @@ def sm_ar1_sim(n, p, g, sig):
     See also
     --------
 
-    pyleoclim.utils.correlation.corr_sig : Estimates the Pearson's correlation and associated significance between two non IID time series
-    pyleoclim.utils.correlation.fdr : Determine significance based on the false discovery rate
+    skyborn.causality.granger_causality : Granger causality analysis
+    skyborn.causality.liang_causality : Liang information flow analysis
 
     """
     # specify model parameters (statsmodel wants lag0 coefficents as unity)
@@ -99,7 +105,13 @@ def sm_ar1_sim(n, p, g, sig):
 # --------
 
 
-def granger_causality(y1, y2, maxlag=1, addconst=True, verbose=True):
+def granger_causality(
+    y1: np.ndarray,
+    y2: np.ndarray,
+    maxlag: Union[int, List[int]] = 1,
+    addconst: bool = True,
+    verbose: bool = True,
+) -> Dict[Any, Any]:
     """Granger causality tests
 
     Four tests for the Granger non-causality of 2 time series.
@@ -140,11 +152,11 @@ def granger_causality(y1, y2, maxlag=1, addconst=True, verbose=True):
     See also
     --------
 
-    pyleoclim.utils.causality.liang_causality : information flow estimated using the Liang algorithm
+    skyborn.causality.liang_causality : Information flow estimated using the Liang algorithm
 
-    pyleoclim.utils.causality.signif_isopersist : significance test with AR(1) with same persistence
+    skyborn.causality.signif_isopersist : Significance test with AR(1) with same persistence
 
-    pyleoclim.utils.causality.signif_isospec : significance test with surrogates with randomized phases
+    skyborn.causality.signif_isospec : Significance test with surrogates with randomized phases
 
     References
     ----------
@@ -165,7 +177,7 @@ def granger_causality(y1, y2, maxlag=1, addconst=True, verbose=True):
     return res
 
 
-def phaseran(recblk, nsurr):
+def phaseran(recblk: np.ndarray, nsurr: int) -> np.ndarray:
     """Simultaneous phase randomization of a set of time series
 
     It creates blocks of surrogate data with the same second order properties as the original
@@ -195,8 +207,8 @@ def phaseran(recblk, nsurr):
     See also
     --------
 
-    pyleoclim.utils.correlation.corr_sig : Estimates the Pearson's correlation and associated significance between two non IID time series
-    pyleoclim.utils.correlation.fdf : Determine significance based on the false discovery rate
+    skyborn.causality.liang_causality : Liang-Kleeman information flow analysis
+    skyborn.causality.granger_causality : Granger causality analysis
 
     References
     ----------
@@ -241,13 +253,13 @@ def phaseran(recblk, nsurr):
 
 
 def liang_causality(
-    y1,
-    y2,
-    npt=1,
-    signif_test="isospec",
-    nsim=1000,
-    qs=[0.005, 0.025, 0.05, 0.95, 0.975, 0.995],
-):
+    y1: np.ndarray,
+    y2: np.ndarray,
+    npt: int = 1,
+    signif_test: str = "isospec",
+    nsim: int = 1000,
+    qs: List[float] = [0.005, 0.025, 0.05, 0.95, 0.975, 0.995],
+) -> Dict[str, Any]:
     """Liang-Kleeman information flow
 
     Estimate the Liang information transfer from series y2 to series y1 with
@@ -286,10 +298,10 @@ def liang_causality(
 
     See also
     --------
-    pyleoclim.utils.causality.liang : information flow estimated using the Liang algorithm
-    pyleoclim.utils.causality.granger_causality : information flow estimated using the Granger algorithm
-    pyleoclim.utils.causality.signif_isopersist : significance test with AR(1) with same persistence
-    pyleoclim.utils.causality.causality.signif_isospec : significance test with surrogates with randomized phases
+    skyborn.causality.liang : Information flow estimated using the Liang algorithm
+    skyborn.causality.granger_causality : Information flow estimated using the Granger algorithm
+    skyborn.causality.signif_isopersist : Significance test with AR(1) with same persistence
+    skyborn.causality.signif_isospec : Significance test with surrogates with randomized phases
 
     References
     ----------
@@ -393,7 +405,7 @@ def liang_causality(
     return res
 
 
-def liang(y1, y2, npt=1):
+def liang(y1: np.ndarray, y2: np.ndarray, npt: int = 1) -> Dict[str, float]:
     """
     Estimate the Liang information transfer from series y2 to series y1
 
@@ -421,10 +433,10 @@ def liang(y1, y2, npt=1):
     See also
     --------
 
-    pyleoclim.utils.causality.liang_causality : information flow estimated using the Liang algorithm
-    pyleoclim.utils.causality.granger_causality : information flow estimated using the Granger algorithm
-    pyleoclim.utils.causality.signif_isopersist : significance test with AR(1) with same persistence
-    pyleoclim.utils.causality.signif_isospec : significance test with surrogates with randomized phases
+    skyborn.causality.liang_causality : Information flow estimated using the Liang algorithm
+    skyborn.causality.granger_causality : Information flow estimated using the Granger algorithm
+    skyborn.causality.signif_isopersist : Significance test with AR(1) with same persistence
+    skyborn.causality.signif_isospec : Significance test with surrogates with randomized phases
 
     References
     ----------
@@ -519,8 +531,13 @@ def liang(y1, y2, npt=1):
 
 
 def signif_isopersist(
-    y1, y2, method, nsim=1000, qs=[0.005, 0.025, 0.05, 0.95, 0.975, 0.995], **kwargs
-):
+    y1: np.ndarray,
+    y2: np.ndarray,
+    method: str,
+    nsim: int = 1000,
+    qs: list[float] = [0.005, 0.025, 0.05, 0.95, 0.975, 0.995],
+    **kwargs,
+) -> dict[str, np.ndarray]:
     """significance test with AR(1) with same persistence
 
     Parameters
@@ -551,9 +568,9 @@ def signif_isopersist(
     See also
     --------
 
-    pyleoclim.utils.causality.liang_causality : information flow estimated using the Liang algorithm
-    pyleoclim.utils.causality.granger_causality : information flow estimated using the Granger algorithm
-    pyleoclim.utils.causality.signif_isospec : significance test with surrogates with randomized phases
+    skyborn.causality.liang_causality : Information flow estimated using the Liang algorithm
+    skyborn.causality.granger_causality : Information flow estimated using the Granger algorithm
+    skyborn.causality.signif_isospec : Significance test with surrogates with randomized phases
 
     """
     g1 = ar1_fit_evenly(y1)
@@ -589,8 +606,13 @@ def signif_isopersist(
 
 
 def signif_isospec(
-    y1, y2, method, nsim=1000, qs=[0.005, 0.025, 0.05, 0.95, 0.975, 0.995], **kwargs
-):
+    y1: np.ndarray,
+    y2: np.ndarray,
+    method: str,
+    nsim: int = 1000,
+    qs: list[float] = [0.005, 0.025, 0.05, 0.95, 0.975, 0.995],
+    **kwargs,
+) -> dict[str, np.ndarray]:
     """significance test with surrogates with randomized phases
 
     Parameters
@@ -618,9 +640,9 @@ def signif_isospec(
     See also
     --------
 
-    pyleoclim.utils.causality.liang_causality : information flow estimated using the Liang algorithm
-    pyleoclim.utils.causality.granger_causality : information flow estimated using the Granger algorithm
-    pyleoclim.utils.causality.signif_isopersist : significance test with AR(1) with same persistence
+    skyborn.causality.liang_causality : Information flow estimated using the Liang algorithm
+    skyborn.causality.granger_causality : Information flow estimated using the Granger algorithm
+    skyborn.causality.signif_isopersist : Significance test with AR(1) with same persistence
 
     """
 
