@@ -8,6 +8,8 @@ Author: Qianye Su
 Email: suqianye2000@gmail.com
 """
 
+import subprocess  # For testing patches
+
 from .grib_to_netcdf import (
     convert_grib_to_nc,
     convert_grib_to_nc_simple,
@@ -15,6 +17,10 @@ from .grib_to_netcdf import (
     grib2nc,
     grib_to_netcdf,
     GribToNetCDFError,
+    # Private functions for testing
+    _check_grib_to_netcdf_available,
+    _validate_grib_files,
+    _build_grib_to_netcdf_command,
 )
 
 __all__ = [
@@ -24,4 +30,8 @@ __all__ = [
     "grib2nc",
     "grib_to_netcdf",
     "GribToNetCDFError",
+    # Private functions (for testing)
+    "_check_grib_to_netcdf_available",
+    "_validate_grib_files",
+    "_build_grib_to_netcdf_command",
 ]
